Learn R Programming

lordif (version 0.1-9)

montecarlo: performs Monte Carlo simulations for empirical cutoff thresholds

Description

performs Monte Carlo simulations under no-DIF conditions to generate empirical cutoff thresholds

Usage

montecarlo(obj, alpha = 0.01, nr = 100)

Arguments

obj
an object returned from lordif
alpha
desired significance level (e.g., .01)
nr
number of replications

Value

  • Returns a list of class "lordif.MC" with the following components:
  • callcalling expression
  • chi12prob associated with the LR Chi-square test comparing Model 1 vs. 2
  • chi13prob associated with the LR Chi-square test comparing Model 1 vs. 3
  • chi23prob associated with the LR Chi-square test comparing Model 2 vs. 3
  • pseudo12.CoxSnellCox & Snell pseudo R-square change from Model 1 to 2
  • pseudo13.CoxSnellCox & Snell pseudo R-square change from Model 1 to 3
  • pseudo23.CoxSnellCox & Snell pseudo R-square change from Model 2 to 3
  • pseudo12.NagelkerkeNagelkerke pseudo R-square change from Model 1 to 2
  • pseudo13.NagelkerkeNagelkerke pseudo R-square change from Model 1 to 3
  • pseudo23.NagelkerkeNagelkerke pseudo R-square change from Model 2 to 3
  • pseudo12.McFaddenMcFadden pseudo R-square change from Model 1 to 2
  • pseudo13.McFaddenMcFadden pseudo R-square change from Model 1 to 3
  • pseudo23.McFaddenMcFadden pseudo R-square change from Model 2 to 3
  • beta12proportional beta change from Model 1 to 2
  • alphasignificance level
  • nrnumber of replications
  • cutoffthresholds for the statistics

Details

Simulated datasets are generated under no-DIF conditions and have the same dimensions as the empirical dataset. Group differences (impact) in theta estimates are preserved in the simulated datasets. Returns empirical thresholds for various statistics and effect size measures.

References

Crane, P. K., Gibbons, L. E., Jolley, L., and van Belle, G. (2006). Differential item functioning analysis with ordinal logistic regression techniques: DIF detect and difwithpar. Medical Care, 44(11 Suppl 3), S115-S123.

See Also

lordif

Examples

Run this code
##load PROMIS Anxiety sample data (n=766)
  data(Anxiety)
##age : 0=younger than 65 or 1=65 or older
##run age-related DIF on all 29 items (takes about a minute)
  age.DIF <- lordif(Anxiety[paste("R",1:29,sep="")],Anxiety$age) 
##the following takes several minutes
  age.DIF.MC <- montecarlo(age.DIF,alpha=0.01,nr=100)

Run the code above in your browser using DataLab